#

##

##

##

##

    	HTTPS certificates

    	summary

    		This might make sense with CloudFlare.

    	possibilities

    		[ ] ZeroSSL SSL Certificates:
    			https://github.com/zerossl/zerossl-bot

    	objectives

    	certbot

    		https://certbot.eff.org/instructions?ws=haproxy&os=fedora

    		install:
    			sudo snap install --classic certbot

    		not running:
    			sudo certbot certonly --webroot

    		running:
    			sudo certbot certonly --standalone
    			certbot certonly --standalone --preferred-challenges http -m address@goodestsink.com -d goodestsink.com

    		ensure repeated updates:
    			sudo certbot renew --dry-run